==> magic3_2.7.4_src.tar.gz: magic3/scripts/kcfinder-2.51/config.php <==
<?php

/** This file is part of KCFinder project
  *
  *      @desc Base configuration file
  *   @package KCFinder
  *   @version 2.51
  *    @author Pavel Tzonkov <pavelc@users.sourceforge.net>
  * @copyright 2010, 2011 KCFinder Project
  *   @license http://www.opensource.org/licenses/gpl-2.0.php GPLv2
  *   @license http://www.opensource.org/licenses/lgpl-2.1.php LGPLv2
  *      @link http://kcfinder.sunhater.com
  */

// IMPORTANT!!! Do not remove uncommented settings in this file even if
// you are using session configuration.
// See http://kcfinder.sunhater.com/install for setting descriptions
global $gEnvManager;

$_CONFIG = array(

    'disabled' => false,
    'denyZipDownload' => false,
    'denyUpdateCheck' => true,		// 新規バージョンチェックなし
    'denyExtensionRename' => false,

    'theme' => "oxygen",

    //'uploadURL' => "upload",
	'uploadURL' => $gEnvManager->getRelativeResourcePathToDocumentRootForUser(),	// リソースディレクトリを設定
    'uploadDir' => "",

    'dirPerms'	=> M3_SYSTEM_DIR_PERMISSION,
    'filePerms'	=> M3_SYSTEM_FILE_PERMISSION,

    'access' => array(

        'files' => array(
            'upload' => true,
            'delete' => true,
            'copy' => true,
            'move' => true,
            'rename' => true
        ),

        'dirs' => array(
            'create' => true,
            'delete' => true,
            'rename' => true
        )
    ),

    'deniedExts' => "exe com msi bat php phps phtml php3 php4 cgi pl",

	// 作成するディレクトリとファイルタイプ
    'types' => array(
//		'files'   =>  "",
//		'images'  =>  "*img",
		'file'    =>  "",
		'image'   =>  "*img",
		'flash'   =>  "swf",
		'media'   =>  "swf flv avi mpg mpeg qt mov wmv asf rm",
    ),

	// ファイル名、ディレクトリ名自動変換
	'filenameChangeChars' => array(
		' ' => "_",
		/*':' => "."*/
	),
	'dirnameChangeChars' => array(
		' ' => "_",
		/*':' => "."*/
	),

    'mime_magic' => "",

    'maxImageWidth' => 0,
    'maxImageHeight' => 0,

    'thumbWidth' => 100,
    'thumbHeight' => 100,

    'thumbsDir' => ".thumbs",

    'jpegQuality' => 90,

    'cookieDomain' => "",
    'cookiePath' => "",
    'cookiePrefix' => 'KCFINDER_',

    // THE FOLLOWING SETTINGS CANNOT BE OVERRIDED WITH SESSION CONFIGURATION
    '_check4htaccess' => true,
    //'_tinyMCEPath' => "/tiny_mce",

    '_sessionVar' => &$_SESSION['KCFINDER'],
    //'_sessionLifetime' => 30,
    //'_sessionDir' => "/full/directory/path",

    //'_sessionDomain' => ".mysite.com",
    //'_sessionPath' => "/my/path",
);

?>

==> magic3_2.8.15_src.tar.gz: magic3/scripts/kcfinder-2.51/config.php <==
<?php

/** This file is part of KCFinder project
  *
  *      @desc Base configuration file
  *   @package KCFinder
  *   @version 2.51
  *    @author Pavel Tzonkov <pavelc@users.sourceforge.net>
  * @copyright 2010, 2011 KCFinder Project
  *   @license http://www.opensource.org/licenses/gpl-2.0.php GPLv2
  *   @license http://www.opensource.org/licenses/lgpl-2.1.php LGPLv2
  *      @link http://kcfinder.sunhater.com
  */

// IMPORTANT!!! Do not remove uncommented settings in this file even if
// you are using session configuration.
// See http://kcfinder.sunhater.com/install for setting descriptions
global $gEnvManager;

$_CONFIG = array(

    'disabled' => false,
    'denyZipDownload' => false,
    'denyUpdateCheck' => true,		// 新規バージョンチェックなし
    'denyExtensionRename' => false,

    'theme' => "oxygen",

    //'uploadURL' => "upload",
//	'uploadURL' => $gEnvManager->getRelativeResourcePathToDocumentRootForUser(),	// リソースディレクトリを設定
//	'uploadDir' => "",
	'uploadURL' => $gEnvManager->getResourceUrlForUser(),		// リソースURL
	'uploadDir' => $gEnvManager->getResourcePathForUser(),		// リソースディレクトリ

    'dirPerms'	=> M3_SYSTEM_DIR_PERMISSION,
    'filePerms'	=> M3_SYSTEM_FILE_PERMISSION,

    'access' => array(

        'files' => array(
            'upload' => true,
            'delete' => true,
            'copy' => true,
            'move' => true,
            'rename' => true
        ),

        'dirs' => array(
            'create' => true,
            'delete' => true,
            'rename' => true
        )
    ),

    'deniedExts' => "exe com msi bat php phps phtml php3 php4 cgi pl",

	// 作成するディレクトリとファイルタイプ
    'types' => array(
//		'files'   =>  "",
//		'images'  =>  "*img",
		'file'    =>  "",
		'image'   =>  "*img",
		'flash'   =>  "swf",
		'media'   =>  "swf flv avi mpg mpeg qt mov wmv asf rm",
    ),

	// ファイル名、ディレクトリ名自動変換
	'filenameChangeChars' => array(
		' ' => "_",
		/*':' => "."*/
	),
	'dirnameChangeChars' => array(
		' ' => "_",
		/*':' => "."*/
	),

    'mime_magic' => "",

    'maxImageWidth' => 0,
    'maxImageHeight' => 0,

    'thumbWidth' => 100,
    'thumbHeight' => 100,

    'thumbsDir' => ".thumbs",

    'jpegQuality' => 90,

    'cookieDomain' => "",
    'cookiePath' => "",
    'cookiePrefix' => 'KCFINDER_',

    // THE FOLLOWING SETTINGS CANNOT BE OVERRIDED WITH SESSION CONFIGURATION
    '_check4htaccess' => true,
    //'_tinyMCEPath' => "/tiny_mce",

    '_sessionVar' => &$_SESSION['KCFINDER'],
    //'_sessionLifetime' => 30,
    //'_sessionDir' => "/full/directory/path",

    //'_sessionDomain' => ".mysite.com",
    //'_sessionPath' => "/my/path",
);

?>
